@@ -46,7 +46,8 @@ class OrderDetailsProxy(VTIXyProxyView):
         response = super(OrderDetailsProxy, self).get(request, *args, **kwargs)
 
         transaction_parts = response.data['transaction_id'].split('.')
-        if request.GET['transaction_id'] != transaction_parts[0]:
+        order_is_sold = response.data['sold']
+        if order_is_sold and request.GET['transaction_id'] != transaction_parts[0]:
             raise Http404
 
         return response
\ No newline at end of file
